@@ -19,14 +19,21 @@ pub struct AppState {
 /// Creates a new agent, if neccessary.
 pub fn init(config: Config) -> BetterResult<AppState> {
     let store = atomic_lib::Db::init(&config.store_path, config.local_base_url.clone())?;
+    if config.initialize {
+        log::info!("Initialize: creating and populating new Database...");
+        atomic_lib::populate::populate_default_store(&store)?;
+        // Building the index here is needed to perform TPF queries on imported resources
+        store.build_index(true)?;
+    }
     set_default_agent(&config, &store)?;
-    // TODO: implement logic that checks if this is the first time that the server is started.
-    let initial = true;
-    if initial {
-        store.populate()?;
+    if config.initialize {
+        atomic_lib::populate::populate_hierarchy(&store)?;
+        atomic_lib::populate::populate_collections(&store)?;
+        atomic_lib::populate::populate_endpoints(&store)?;
         set_up_initial_invite(&store)?;
+        // This means that editing the .env does _not_ grant you the rights to edit the Drive.
+        set_up_drive(&store)?;
     }
-    set_up_drive(&store)?;
 
     Ok(AppState { store, config })
 }
@@ -92,7 +99,7 @@ fn set_default_agent(config: &Config, store: &impl Storelike) -> BetterResult<()
 /// Creates the first Invitation that is opened by the user on the Home page.
 fn set_up_initial_invite(store: &impl Storelike) -> BetterResult<()> {
     let subject = format!("{}/setup", store.get_base_url());
-    log::info!("Creating initial Invite at {}...", subject);
+    log::info!("Creating initial Invite at {} ...", subject);
     let mut invite = atomic_lib::Resource::new_instance(atomic_lib::urls::INVITE, store)?;
     invite.set_subject(subject);
     // This invite can be used only once
@@ -111,6 +118,11 @@ fn set_up_initial_invite(store: &impl Storelike) -> BetterResult<()> {
         atomic_lib::Value::AtomicUrl(store.get_base_url().into()),
         store,
     )?;
+    invite.set_propval_string(
+        atomic_lib::urls::DESCRIPTION.into(),
+        "Use this Invite to create an Agent, or use an existing one. Accepting will grant your Agent the necessary rights to edit the data in your Atomic Server. This can only be used once. If you, for whatever reason, need a new `/setup` invite, you can pass the `--init` flag to `atomic-server`.",
+        store,
+    )?;
     invite.save_locally(store)?;
     Ok(())
 }
@@ -124,6 +136,7 @@ fn set_up_drive(store: &impl Storelike) -> BetterResult<()> {
     // TODO: add read rights to public, maybe
     drive.set_propval(atomic_lib::urls::WRITE.into(), agents.clone().into(), store)?;
     drive.set_propval(atomic_lib::urls::READ.into(), agents.into(), store)?;
+    drive.set_propval_string(atomic_lib::urls::DESCRIPTION.into(), "Welcome to your Atomic-Server! Register your User by visiting [`/setup`](http://localhost/setup). After that, edit this page by pressing `edit` in the navigation bar menu.", store)?;
     drive.save_locally(store)?;
     Ok(())
 }
