@@ -6,6 +6,7 @@ mod handlers;
 mod helpers;
 mod https;
 mod jsonerrors;
+mod process;
 mod routes;
 #[cfg(feature = "desktop")]
 mod tray_icon;
@@ -21,11 +22,7 @@ async fn main() -> AtomicResult<()> {
     let matches = clap::App::new("atomic-server")
         .version(crate_version!())
         .author("Joep Meindertsma <joep@ontola.io>")
-        .about("Store and share Atomic Data! Visit https://atomicdata.dev for more info")
-        .subcommand(
-            SubCommand::with_name("run")
-                .about("Starts the server (also runs without any arguments)")
-        )
+        .about("Store and share Atomic Data! Visit https://atomicdata.dev for more info. Pass no subcommands to launch the server.")
         .subcommand(
             SubCommand::with_name("export")
                 .about("Create a JSON-AD backup of the store.")
@@ -42,9 +39,17 @@ async fn main() -> AtomicResult<()> {
                     .required(true)
                 )
         )
-        .subcommand(
-            SubCommand::with_name("index")
-                .about("Rebuilds the index, and starts the server.")
+        .arg(
+            Arg::with_name("reindex")
+            .long("reindex")
+            .short("r")
+            .help("Rebuilds the index (can take a while for large stores).")
+        )
+        .arg(
+            Arg::with_name("init")
+            .long("init")
+            .help("Recreates the `/setup` Invite for creating a new Root User. Also re-runs various populate commands, and re-builds the index.")
+            .short("i")
         )
         .get_matches();
 
@@ -56,7 +61,8 @@ async fn main() -> AtomicResult<()> {
     log::info!("Atomic-server {}. Visit https://atomicdata.dev and https://github.com/joepio/atomic for more information.", VERSION);
 
     // Read .env vars, https certs
-    let config = config::init().expect("Error setting config");
+    let config = config::init(&matches).expect("Error setting config");
+    process::check_and_stop_running(&config)?;
     // Initialize DB and HTML templating engine
     let appstate = match appstate::init(config.clone()) {
         Ok(state) => state,
@@ -65,11 +71,14 @@ async fn main() -> AtomicResult<()> {
         }
     };
     let appstate_clone = appstate.clone();
-    let mut build_index = !appstate_clone.store.has_index();
 
     match matches.subcommand_name() {
         Some("export") => {
-            let path = match matches.subcommand_matches("export").unwrap().value_of("path") {
+            let path = match matches
+                .subcommand_matches("export")
+                .unwrap()
+                .value_of("path")
+            {
                 Some(p) => std::path::Path::new(p).to_path_buf(),
                 None => {
                     let date = chrono::Local::now().to_rfc3339();
@@ -77,19 +86,24 @@ async fn main() -> AtomicResult<()> {
                     let mut pt = config.config_dir;
                     pt.push(&pathstr);
                     pt
-                },
+                }
             };
             let outstr = appstate.store.export(true)?;
             std::fs::create_dir_all(path.parent().unwrap())
                 .map_err(|e| format!("Failed to create directory {:?}. {}", path, e))?;
-            let mut file = File::create(&path).map_err(|e| format!("Failed to write file to {:?}. {}", path, e))?;
+            let mut file = File::create(&path)
+                .map_err(|e| format!("Failed to write file to {:?}. {}", path, e))?;
             use std::io::Write;
             write!(file, "{}", outstr)?;
             println!("Succesfully exported data to {}", path.to_str().unwrap());
             std::process::exit(0);
         }
         Some("import") => {
-            let pathstr = matches.subcommand_matches("import").unwrap().value_of("path").unwrap();
+            let pathstr = matches
+                .subcommand_matches("import")
+                .unwrap()
+                .value_of("path")
+                .unwrap();
             let path = std::path::Path::new(pathstr);
             let readstring = std::fs::read_to_string(path)?;
 
@@ -101,29 +115,32 @@ async fn main() -> AtomicResult<()> {
         Some("run") => {
             // continue, start server
         }
-        Some("index") => {
-            build_index = true;
-        }
         Some(unkown) => {
             panic!("Unkown command: {}", unkown);
         }
         None => {
             // Start server if no command is found
-        },
+        }
     };
 
     // Start other async processes
     #[cfg(feature = "desktop")]
     tray_icon::tray_icon_process(config.clone());
 
-    actix_web::rt::spawn(async move {
-        if build_index {
+    if config.rebuild_index {
+        actix_web::rt::spawn(async move {
             log::warn!("Building index... This could take a while, expect worse performance until 'Building index finished'");
-            appstate_clone.store.clear_index().expect("Failed to clear index");
-            appstate_clone.store.build_index(true).expect("Failed to build index");
+            appstate_clone
+                .store
+                .clear_index()
+                .expect("Failed to clear index");
+            appstate_clone
+                .store
+                .build_index(true)
+                .expect("Failed to build index");
             log::info!("Building index finished!");
-        }
-    });
+        });
+    }
 
     let server = HttpServer::new(move || {
         let data = web::Data::new(Mutex::new(appstate.clone()));
@@ -137,9 +154,10 @@ async fn main() -> AtomicResult<()> {
             .wrap(middleware::Logger::default())
             .wrap(middleware::Compress::default())
             .configure(routes::config_routes)
-            .default_service(
-                web::to(|| {log::error!("Wrong route, should not happen with normal requests"); actix_web::HttpResponse::NotFound()})
-            )
+            .default_service(web::to(|| {
+                log::error!("Wrong route, should not happen with normal requests");
+                actix_web::HttpResponse::NotFound()
+            }))
             .app_data(
                 web::JsonConfig::default()
                     // register error_handler for JSON extractors.
@@ -164,7 +182,6 @@ async fn main() -> AtomicResult<()> {
             .expect(&*format!("Cannot bind to endpoint {}", &endpoint))
             .run()
             .await?;
-        Ok(())
     } else {
         let endpoint = format!("{}:{}", config.ip, config.port);
         println!("{}", message);
@@ -173,8 +190,10 @@ async fn main() -> AtomicResult<()> {
             .expect(&*format!("Cannot bind to endpoint {}", &endpoint))
             .run()
             .await?;
-        Ok(())
     }
+    process::remove_pid(&config)?;
+
+    Ok(())
 }
 
 const BANNER: &str = r#"
