@@ -9,7 +9,7 @@ pub fn config_routes(app: &mut actix_web::web::ServiceConfig) {
             web::resource("/*")
                 .guard(actix_web::guard::Method(Method::GET))
                 .guard(actix_web::guard::fn_guard(|head| {
-                    content_types::get_accept(&head.headers()) == content_types::ContentType::HTML
+                    content_types::get_accept(&head.headers()) == content_types::ContentType::Html
                 }))
                 .to(handlers::single_page_app::single_page),
         )
@@ -26,7 +26,5 @@ pub fn config_routes(app: &mut actix_web::web::ServiceConfig) {
                 .service(web::resource("").route(web::get().to(handlers::resource::get_resource))),
         )
         // Also allow the home resource
-        .service(
-            web::resource("/").to(handlers::resource::get_resource),
-        );
+        .service(web::resource("/").to(handlers::resource::get_resource));
 }
